@@ -2,19 +2,16 @@ from copy import deepcopy
 from typing import Optional
 
 import numpy as np
-from anndata import AnnData
 
 from scvi import REGISTRY_KEYS
 
 from . import _constants
-from ._manager import AnnDataManager
 from .fields import (
     CategoricalJointObsField,
     CategoricalObsField,
     LabelsWithUnlabeledObsField,
     LayerField,
     NumericalJointObsField,
-    NumericalObsField,
     ProteinObsmField,
 )
 
@@ -29,8 +26,56 @@ LEGACY_REGISTRY_KEY_MAP = {
 }
 
 
+def _infer_setup_args(
+    model_cls, setup_dict: dict, unlabeled_category: Optional[str]
+) -> dict:
+    setup_args = dict()
+    data_registry = setup_dict[_constants._DATA_REGISTRY_KEY]
+    categorical_mappings = setup_dict["categorical_mappings"]
+    for registry_key, adata_mapping in data_registry.items():
+        if registry_key not in LEGACY_REGISTRY_KEY_MAP:
+            continue
+        new_registry_key = LEGACY_REGISTRY_KEY_MAP[registry_key]
+
+        attr_name = adata_mapping[_constants._DR_ATTR_NAME]
+        attr_key = adata_mapping[_constants._DR_ATTR_KEY]
+        if attr_name == _constants._ADATA_ATTRS.X:
+            setup_args["layer"] = None
+        elif attr_name == _constants._ADATA_ATTRS.LAYERS:
+            setup_args["layer"] = attr_key
+        elif attr_name == _constants._ADATA_ATTRS.OBS:
+            if new_registry_key in {REGISTRY_KEYS.BATCH_KEY, REGISTRY_KEYS.LABELS_KEY}:
+                # Omit labels field for TOTALVI
+                if (
+                    model_cls.__name__ == "TOTALVI"
+                    and new_registry_key == REGISTRY_KEYS.LABELS_KEY
+                ):
+                    continue
+                setup_args[f"{new_registry_key}_key"] = categorical_mappings[attr_key][
+                    "original_key"
+                ]
+        elif attr_name == _constants._ADATA_ATTRS.OBSM:
+            if new_registry_key == REGISTRY_KEYS.CONT_COVS_KEY:
+                obs_keys = setup_dict["extra_continuous_keys"]
+                setup_args["continuous_covariate_keys"] = obs_keys
+            elif new_registry_key == REGISTRY_KEYS.CAT_COVS_KEY:
+                obs_keys = setup_dict["extra_categoricals"]["keys"]
+                setup_args["categorical_covariate_keys"] = obs_keys
+            elif new_registry_key == REGISTRY_KEYS.PROTEIN_EXP_KEY:
+                setup_args["protein_expression_obsm_key"] = attr_key
+                setup_args["protein_names_uns_key"] = "_protein_names"
+
+    if unlabeled_category is not None:
+        setup_args["unlabeled_category"] = unlabeled_category
+
+    return {
+        _constants._MODEL_NAME_KEY: model_cls.__name__,
+        _constants._SETUP_ARGS_KEY: setup_args,
+    }
+
+
 def registry_from_setup_dict(
-    setup_dict: dict, unlabeled_category: Optional[str] = None
+    model_cls, setup_dict: dict, unlabeled_category: Optional[str] = None
 ) -> dict:
     """
     Converts old setup dict format to new registry dict format.
@@ -40,8 +85,12 @@ def registry_from_setup_dict(
 
     Parameters
     ----------
+    model_cls
+        Model class used for setup.
     setup_dict
         Setup dictionary created after registering an AnnData with former ``setup_anndata`` implementation.
+    unlabeled_category
+        Unlabeled category value used in :class:`~scvi.model.SCANVI`.
     """
     registry = {
         _constants._SCVI_VERSION_KEY: setup_dict[_constants._SCVI_VERSION_KEY],
@@ -61,6 +110,8 @@ def registry_from_setup_dict(
 
         attr_name = adata_mapping[_constants._DR_ATTR_NAME]
         attr_key = adata_mapping[_constants._DR_ATTR_KEY]
+        if attr_key is not None and attr_key.startswith("_scvi"):
+            adata_mapping[_constants._DR_ATTR_KEY] = f"_scvi_{new_registry_key}"
 
         field_registries[new_registry_key] = {
             _constants._DATA_REGISTRY_KEY: adata_mapping,
@@ -77,9 +128,21 @@ def registry_from_setup_dict(
             field_summary_stats.update(field_state_registry)
         elif attr_name == _constants._ADATA_ATTRS.OBS:
             categorical_mapping = categorical_mappings[attr_key]
+            # Default labels field for TOTALVI
+            if (
+                model_cls.__name__ == "TOTALVI"
+                and new_registry_key == REGISTRY_KEYS.LABELS_KEY
+            ):
+                field_state_registry[
+                    CategoricalObsField.CATEGORICAL_MAPPING_KEY
+                ] = np.zeros(1, dtype=np.int64)
+            else:
+                field_state_registry[
+                    CategoricalObsField.CATEGORICAL_MAPPING_KEY
+                ] = categorical_mapping["mapping"]
             field_state_registry[
-                CategoricalObsField.CATEGORICAL_MAPPING_KEY
-            ] = categorical_mapping["mapping"]
+                CategoricalObsField.ORIGINAL_ATTR_KEY
+            ] = categorical_mapping["original_key"]
             if new_registry_key == REGISTRY_KEYS.BATCH_KEY:
                 field_summary_stats[f"n_{new_registry_key}"] = summary_stats["n_batch"]
             elif new_registry_key == REGISTRY_KEYS.LABELS_KEY:
@@ -95,7 +158,10 @@ def registry_from_setup_dict(
                 field_summary_stats[f"n_{new_registry_key}"] = columns.shape[0]
             elif new_registry_key == REGISTRY_KEYS.CAT_COVS_KEY:
                 extra_categoricals_mapping = deepcopy(setup_dict["extra_categoricals"])
-                field_state_registry.update(deepcopy(setup_dict["extra_categoricals"]))
+                field_state_registry.update(extra_categoricals_mapping)
+                field_state_registry[
+                    CategoricalJointObsField.FIELD_KEYS_KEY
+                ] = field_state_registry.pop("keys")
                 field_summary_stats[f"n_{new_registry_key}"] = len(
                     extra_categoricals_mapping["keys"]
                 )
@@ -110,107 +176,7 @@ def registry_from_setup_dict(
                 field_summary_stats[f"n_{new_registry_key}"] = len(
                     setup_dict["protein_names"]
                 )
+
+    registry.update(_infer_setup_args(model_cls, setup_dict, unlabeled_category))
+
     return registry
-
-
-def manager_from_setup_dict(
-    cls,
-    adata: AnnData,
-    setup_dict: dict,
-    unlabeled_category: Optional[str] = None,
-    **transfer_kwargs,
-) -> AnnDataManager:
-    """
-    Creates an :class:`~scvi.data.AnnDataManager` given only a scvi-tools setup dictionary.
-
-    Only to be used for backwards compatibility when loading setup dictionaries for models.
-    Infers the AnnDataField instances used to define the :class:`~scvi.data.AnnDataManager` instance,
-    then uses the :meth:`~scvi.data.AnnDataManager.transfer_fields` method to register the new AnnData object.
-
-    Parameters
-    ----------
-    adata
-        AnnData object to be registered.
-    setup_dict
-        Setup dictionary created after registering an AnnData with former ``setup_anndata`` implementation.
-    **kwargs
-        Keyword arguments to modify transfer behavior.
-    """
-    fields = []
-    setup_args = dict()
-    data_registry = setup_dict[_constants._DATA_REGISTRY_KEY]
-    categorical_mappings = setup_dict["categorical_mappings"]
-    for registry_key, adata_mapping in data_registry.items():
-        if registry_key not in LEGACY_REGISTRY_KEY_MAP:
-            continue
-        new_registry_key = LEGACY_REGISTRY_KEY_MAP[registry_key]
-
-        field = None
-        attr_name = adata_mapping[_constants._DR_ATTR_NAME]
-        attr_key = adata_mapping[_constants._DR_ATTR_KEY]
-        if attr_name == _constants._ADATA_ATTRS.X:
-            field = LayerField(REGISTRY_KEYS.X_KEY, None)
-            setup_args["layer"] = None
-        elif attr_name == _constants._ADATA_ATTRS.LAYERS:
-            field = LayerField(REGISTRY_KEYS.X_KEY, attr_key)
-            setup_args["layer"] = attr_key
-        elif attr_name == _constants._ADATA_ATTRS.OBS:
-            if new_registry_key in {REGISTRY_KEYS.BATCH_KEY, REGISTRY_KEYS.LABELS_KEY}:
-                original_key = categorical_mappings[attr_key]["original_key"]
-                if (
-                    unlabeled_category is not None
-                    and new_registry_key == REGISTRY_KEYS.LABELS_KEY
-                ):
-                    field = LabelsWithUnlabeledObsField(
-                        new_registry_key, original_key, unlabeled_category
-                    )
-                else:
-                    field = CategoricalObsField(new_registry_key, original_key)
-                setup_args[f"{new_registry_key}_key"] = original_key
-            elif new_registry_key == REGISTRY_KEYS.INDICES_KEY:
-                adata.obs[attr_key] = np.arange(adata.n_obs).astype("int64")
-                field = NumericalObsField(new_registry_key, attr_key)
-        elif attr_name == _constants._ADATA_ATTRS.OBSM:
-            if new_registry_key == REGISTRY_KEYS.CONT_COVS_KEY:
-                obs_keys = setup_dict["extra_continuous_keys"]
-                field = NumericalJointObsField(REGISTRY_KEYS.CONT_COVS_KEY, obs_keys)
-                setup_args["continuous_covariate_keys"] = obs_keys
-            elif new_registry_key == REGISTRY_KEYS.CAT_COVS_KEY:
-                obs_keys = setup_dict["extra_categoricals"]["keys"]
-                field = CategoricalJointObsField(REGISTRY_KEYS.CAT_COVS_KEY, obs_keys)
-                setup_args["categorical_covariate_keys"] = obs_keys
-            elif new_registry_key == REGISTRY_KEYS.PROTEIN_EXP_KEY:
-                protein_names = setup_dict["protein_names"]
-                adata.uns["_protein_names"] = protein_names
-                field = ProteinObsmField(
-                    REGISTRY_KEYS.PROTEIN_EXP_KEY,
-                    attr_key,
-                    use_batch_mask=True,
-                    batch_key="_scvi_batch",
-                    colnames_uns_key="_protein_names",
-                )
-                setup_args["protein_expression_obsm_key"] = attr_key
-                setup_args["protein_names_uns_key"] = "_protein_names"
-            else:
-                raise NotImplementedError(
-                    f"Unrecognized .obsm attribute {attr_key} registered as {new_registry_key}. Backwards compatibility unavailable."
-                )
-        else:
-            raise NotImplementedError(
-                f"Backwards compatibility for attribute {attr_name} is not implemented."
-            )
-        fields.append(field)
-
-    setup_method_args = {
-        _constants._MODEL_NAME_KEY: cls.__name__,
-        _constants._SETUP_ARGS_KEY: setup_args,
-    }
-    adata_manager = AnnDataManager(fields=fields, setup_method_args=setup_method_args)
-
-    source_registry = registry_from_setup_dict(
-        setup_dict, unlabeled_category=unlabeled_category
-    )
-    adata_manager.register_fields(
-        adata, source_registry=source_registry, **transfer_kwargs
-    )
-    return adata_manager
