@@ -497,9 +497,9 @@ class RNASeqMixin:
             mean_list += [px_rate.cpu().numpy()]
             dropout_list += [px_dropout.cpu().numpy()]
 
-        dropout = np.concatenate(dropout_list)
-        means = np.concatenate(mean_list)
-        dispersions = np.concatenate(dispersion_list)
+        dropout = np.concatenate(dropout_list, axis=-2)
+        means = np.concatenate(mean_list, axis=-2)
+        dispersions = np.concatenate(dispersion_list, axis=-2)
         if give_mean and n_samples > 1:
             dropout = dropout.mean(0)
             means = means.mean(0)
